@@ -82,19 +82,19 @@ class LinuxPartitionTable(object):
     def get_disk_drive(self):
         return self._disk_drive
 
-    def create_partition_for_whole_table(self, file_system_object):
-        self._disk_drive._get_parted_disk_drive().create_partition_for_whole_drive(file_system_object.get_name())
+    def create_partition_for_whole_table(self, file_system_object, alignment_in_bytes=None):
+        self._disk_drive._get_parted_disk_drive().create_partition_for_whole_drive(file_system_object.get_name(), alignment_in_bytes)
         clear_cache(self)
         return self.get_partitions()[0]
 
 class LinuxMBRPartitionTable(LinuxPartitionTable, partition.MBRPartitionTable):
     @classmethod
-    def create_partition_table(cls, disk_drive):
-        disk_drive._get_parted_disk_drive().create_a_new_partition_table("msdos")
+    def create_partition_table(cls, disk_drive, alignment_in_bytes=None):
+        disk_drive._get_parted_disk_drive().create_a_new_partition_table("msdos", alignment_in_bytes)
         return cls(disk_drive)
 
 class LinuxGPTPartitionTable(LinuxPartitionTable, partition.GPTPartitionTable):
     @classmethod
-    def create_partition_table(cls, disk_drive):
-        disk_drive._get_parted_disk_drive().create_a_new_partition_table("gpt")
+    def create_partition_table(cls, disk_drive, alignment_in_bytes=None):
+        disk_drive._get_parted_disk_drive().create_a_new_partition_table("gpt", alignment_in_bytes)
         return cls(disk_drive)
